@@ -1,10 +1,12 @@
-package IPC::SRLock::Fcntl;
+# @(#)$Id: Fcntl.pm 116 2009-06-06 15:52:09Z pjf $
 
-# @(#)$Id: Fcntl.pm 94 2009-02-12 12:00:07Z pjf $
+package IPC::SRLock::Fcntl;
 
 use strict;
 use warnings;
+use version; our $VERSION = qv( sprintf '0.2.%d', q$Rev: 116 $ =~ /\d+/gmx );
 use parent qw(IPC::SRLock);
+
 use Data::Serializer;
 use File::Spec;
 use File::Spec::Functions;
@@ -13,8 +15,6 @@ use IO::AtomicFile;
 use IO::File;
 use Time::HiRes qw(usleep);
 
-use version; our $VERSION = qv( sprintf '0.2.%d', q$Rev: 94 $ =~ /\d+/gmx );
-
 my %ATTRS = ( lockfile   => undef,
               mode       => oct q(0666),
               serializer => undef,
@@ -69,7 +69,8 @@ sub _read_shmfile {
    umask $self->umask;
 
    unless ($lock = IO::File->new( $self->lockfile, q(w), $self->mode )) {
-      $self->throw( error => q(eCannotWrite), arg1 => $self->lockfile );
+      $self->throw( error => 'File [_1] cannot write',
+                    args  => [ $self->lockfile ] );
    }
 
    flock $lock, LOCK_EX;
@@ -95,7 +96,7 @@ sub _reset {
 
    unless (exists $lock_ref->{ $key }) {
       $self->_release( $lock_file );
-      $self->throw( error => q(eLockNotSet), arg1 => $key );
+      $self->throw( error => 'Lock [_1] not set', args => [ $key ] );
    }
 
    delete $lock_ref->{ $key };
@@ -126,7 +127,7 @@ sub _set {
          $self->_release( $lock_file );
 
          if ($self->patience && $now - $start > $self->patience) {
-            $self->throw( error => q(ePatienceExpired), arg1 => $key );
+            $self->throw( error => 'Lock [_1] timed out', args => [ $key ] );
          }
 
          usleep( 1_000_000 * $self->nap_time );
@@ -146,7 +147,8 @@ sub _write_shmfile {
 
    unless ($wtr = IO::AtomicFile->new( $self->shmfile, q(w), $self->mode )) {
       $self->_release( $lock_file );
-      $self->throw( error => q(eCannotWrite), arg1 => $self->shmfile );
+      $self->throw( error => 'File [_1] cannot write',
+                    args  => [ $self->shmfile ] );
    }
 
    eval { $self->serializer->store( $lock_ref, $wtr ) };
@@ -171,7 +173,7 @@ IPC::SRLock::Fcntl - Set/reset locks using fcntl
 
 =head1 Version
 
-0.2.$Revision: 94 $
+0.2.$Revision: 116 $
 
 =head1 Synopsis
 
