@@ -1,15 +1,15 @@
-package IPC::SRLock::Memcached;
+# @(#)$Id: Memcached.pm 116 2009-06-06 15:52:09Z pjf $
 
-# @(#)$Id: Memcached.pm 94 2009-02-12 12:00:07Z pjf $
+package IPC::SRLock::Memcached;
 
 use strict;
 use warnings;
+use version; our $VERSION = qv( sprintf '0.2.%d', q$Rev: 116 $ =~ /\d+/gmx );
 use parent qw(IPC::SRLock);
+
 use Cache::Memcached;
 use Time::HiRes qw(usleep);
 
-use version; our $VERSION = qv( sprintf '0.2.%d', q$Rev: 94 $ =~ /\d+/gmx );
-
 my %ATTRS = ( lockfile  => q(_lockfile),
               memd      => undef,
               servers   => [ q(localhost:11211) ],
@@ -69,7 +69,8 @@ sub _reset {
          $found = 1 if (delete $recs->{ $key });
          $self->memd->set( $self->shmfile, $recs ) if ($found);
          $self->memd->delete( $self->lockfile );
-         $self->throw( error => q(eLockNotSet), arg1 => $key ) unless ($found);
+         $self->throw( error => 'Lock [_1] not set', args => [ $key ] )
+            unless ($found);
          return 1;
       }
 
@@ -130,7 +131,7 @@ sub _sleep_or_throw {
    my ($self, $start, $now, $key) = @_;
 
    if ($self->patience && $now - $start > $self->patience) {
-      $self->throw( error => q(ePatienceExpired), arg1 => $key );
+      $self->throw( error => 'Lock [_1] timed out', args => [ $key ] );
    }
 
    usleep( 1_000_000 * $self->nap_time );
@@ -149,7 +150,7 @@ IPC::SRLock::Memcached - Set/reset locks using libmemcache
 
 =head1 Version
 
-0.2.$Revision: 94 $
+0.2.$Revision: 116 $
 
 =head1 Synopsis
 
